﻿using Avalonia;
using Avalonia.Controls;
using Avalonia.Markup.Xaml;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Threading.Tasks;

namespace AvaloniaResourceThrows
{
    class Program
    {
        static void Main(string[] args)
        {
            AppBuilder.Configure<App>()
                .UsePlatformDetect()
                .Start<MainWindow>();
        }
    }

    public class App : Application
    {
        public override void Initialize()
        {
            AvaloniaXamlLoader.Load(this);
        }
    }

    public class MainWindow : Window
    {
        private D _vm;
        public MainWindow()
        {
            _vm = new D();
            DataContext = _vm;
            AvaloniaXamlLoader.Load(this);

            var task = _vm.Initialize();
        }
    }

    public class D : INotifyPropertyChanged
    {
        private Item _currentItem;

        public D()
        {
            Items = new ObservableCollection<Item>();
        }

        public async Task Initialize()
        {
            await Task.Delay(100).ConfigureAwait(true);

            Items.Add(new Item());
            CurrentItem = Items[0];
        }

        public ObservableCollection<Item> Items { get; }
        public Item CurrentItem
        {
            get { return _currentItem; }
            set
            {
                _currentItem = value;
                PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(nameof(CurrentItem)));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }

    public class Item
    {
        public string Title => "Item";
    }

    public class C : UserControl
    {
        public C()
        {
            AvaloniaXamlLoader.Load(this);
        }
    }
}
